==> pyQParamWidget-0.0.9.tar.gz: pyQParamWidget-0.0.9/README.md <==
# pyQParamWidget: PyQt5 Parameter Editor Widgets

GH tag | GH release | PyPI | conda-forge
--- | --- | --- | ---
[![tag](https://img.shields.io/github/tag/prjemian/pyQParamWidget.svg)](https://github.com/prjemian/pyQParamWidget/tags) | [![release](https://img.shields.io/github/release/prjemian/pyQParamWidget.svg)](https://github.com/prjemian/pyQParamWidget/releases) | [![PyPi](https://img.shields.io/pypi/v/pyQParamWidget.svg)](https://pypi.python.org/pypi/pyQParamWidget) | [![conda-forge](https://img.shields.io/conda/vn/conda-forge/pyQParamWidget)](https://anaconda.org/conda-forge/pyQParamWidget)

Python version(s) | Unit Tests | Code Coverage | License
--- | --- | --- | ---
[![Python version](https://img.shields.io/pypi/pyversions/pyQParamWidget.svg)](https://pypi.python.org/pypi/pyQParamWidget) | [![Testing](https://github.com/prjemian/pyQParamWidget/actions/workflows/code.yml/badge.svg)](https://github.com/prjemian/pyQParamWidget/actions/workflows/code.yml) | [![Coverage Status](https://coveralls.io/repos/github/prjemian/pyQParamWidget/badge.svg?branch=main)](https://coveralls.io/github/prjemian/pyQParamWidget?branch=main) | [![license: CCA4](https://img.shields.io/badge/license-CCA4-darkblue)](/pyQParamWidget/LICENSE.txt)

A PyQt5 QWidget and QDialog to edit application parameters.

```py
import pyQParamWidget as qpw
```

![View of example tree and editor](./qpw.png)

```text
# -----------------------------------------------------------------------------
# :author:    Pete R. Jemian
# :email:     prjemian@gmail.com
# :copyright: (c) 2024, Pete R. Jemian
#
# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
```

==> pyQParamWidget-0.1.0.tar.gz: pyQParamWidget-0.1.0/README.md <==
# pyQParamWidget: PyQt5 Parameter Editor Widgets

GH tag | GH release | PyPI | conda-forge
--- | --- | --- | ---
[![tag](https://img.shields.io/github/tag/prjemian/pyQParamWidget.svg)](https://github.com/prjemian/pyQParamWidget/tags) | [![release](https://img.shields.io/github/release/prjemian/pyQParamWidget.svg)](https://github.com/prjemian/pyQParamWidget/releases) | [![PyPi](https://img.shields.io/pypi/v/pyQParamWidget.svg)](https://pypi.python.org/pypi/pyQParamWidget) | [![conda-forge](https://img.shields.io/conda/vn/conda-forge/pyQParamWidget)](https://anaconda.org/conda-forge/pyQParamWidget)

Python version(s) | Unit Tests | Code Coverage | License
--- | --- | --- | ---
[![Python version](https://img.shields.io/pypi/pyversions/pyQParamWidget.svg)](https://pypi.python.org/pypi/pyQParamWidget) | [![Testing](https://github.com/prjemian/pyQParamWidget/actions/workflows/code.yml/badge.svg)](https://github.com/prjemian/pyQParamWidget/actions/workflows/code.yml) | [![Coverage Status](https://coveralls.io/repos/github/prjemian/pyQParamWidget/badge.svg?branch=main)](https://coveralls.io/github/prjemian/pyQParamWidget?branch=main) | [![license: CCA4](https://img.shields.io/badge/license-CCA4-darkblue)](/pyQParamWidget/LICENSE.txt)

A PyQt5 editor (QWidget) and tree (QDialog) to edit application parameters.

![View of example tree and editor](./qpw.png)

## Import

```py
import pyQParamWidget as qpw
```

## Install

Install by any of these methods:

- `pip install pyQParamWidget`
- TODO: `conda install -c conda-forge pyQParamWidget`
- `pip install https://github.com/prjemian/pyQParamWidget/archive/main.zip`
- `git clone https://github.com/prjemian/pyQParamWidget` and `pip install -e pyQParamWidget --no-deps`

## References

- documentation: https://prjemian.github.io/pyQParamWidget/
- source: https://github.com/prjemian/pyQParamWidget

## Copyright

```text
# -----------------------------------------------------------------------------
# :author:    Pete R. Jemian
# :email:     prjemian@gmail.com
# :copyright: (c) 2024, Pete R. Jemian
#
# Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
```
